(ultramode
-\n 
(story
-\n    
(title
-100 Mbit/s on Fibre to the home
)title
-\n    
(url
-http://slashdot.org/articles/99/06/06/1440211.shtml
)url
-\n    
(time
-1999-06-06 14:39:59
)time
-\n    
(author
-CmdrTaco
)author
-\n    
(department
-wouldn't-it-be-nice
)department
-\n    
(topic
-internet
)topic
-\n    
(comments
-20
)comments
-\n    
(section
-articles
)section
-\n    
(image
-topicinternet.jpg
)image
-\n  
)story
-\n 
(story
-\n    
(title
-Gimp 1.2 Preview
)title
-\n    
(url
-http://slashdot.org/articles/99/06/06/1438246.shtml
)url
-\n    
(time
-1999-06-06 14:38:40
)time
-\n    
(author
-CmdrTaco
)author
-\n    
(department
-stuff-to-read
)department
-\n    
(topic
-gimp
)topic
-\n    
(comments
-12
)comments
-\n    
(section
-articles
)section
-\n    
(image
-topicgimp.gif
)image
-\n  
)story
-\n 
(story
-\n    
(title
-Sony's AIBO robot Sold Out
)title
-\n    
(url
-http://slashdot.org/articles/99/06/06/1432256.shtml
)url
-\n    
(time
-1999-06-06 14:32:51
)time
-\n    
(author
-CmdrTaco
)author
-\n    
(department
-stuff-to-see
)department
-\n    
(topic
-tech
)topic
-\n    
(comments
-10
)comments
-\n    
(section
-articles
)section
-\n    
(image
-topictech2.jpg
)image
-\n  
)story
-\n 
(story
-\n    
(title
-Ask Slashdot: Another Word for "Hacker"?
)title
-\n    
(url
-http://slashdot.org/askslashdot/99/06/05/1815225.shtml
)url
-\n    
(time
-1999-06-05 20:00:00
)time
-\n    
(author
-Cliff
)author
-\n    
(department
-hacker-vs-cracker
)department
-\n    
(topic
-news
)topic
-\n    
(comments
-385
)comments
-\n    
(section
-askslashdot
)section
-\n    
(image
-topicnews.gif
)image
-\n  
)story
-\n 
(story
-\n    
(title
-Corel Linux FAQ
)title
-\n    
(url
-http://slashdot.org/articles/99/06/05/1842218.shtml
)url
-\n    
(time
-1999-06-05 18:42:06
)time
-\n    
(author
-CmdrTaco
)author
-\n    
(department
-stuff-to-read
)department
-\n    
(topic
-corel
)topic
-\n    
(comments
-164
)comments
-\n    
(section
-articles
)section
-\n    
(image
-topiccorel.gif
)image
-\n  
)story
-\n 
(story
-\n    
(title
-Upside downsides MP3.COM.
)title
-\n    
(url
-http://slashdot.org/articles/99/06/05/1558210.shtml
)url
-\n    
(time
-1999-06-05 15:56:45
)time
-\n    
(author
-CmdrTaco
)author
-\n    
(department
-stuff-to-think-about
)department
-\n    
(topic
-music
)topic
-\n    
(comments
-48
)comments
-\n    
(section
-articles
)section
-\n    
(image
-topicmusic.gif
)image
-\n  
)story
-\n 
(story
-\n    
(title
-2 Terabits of Bandwidth
)title
-\n    
(url
-http://slashdot.org/articles/99/06/05/1554258.shtml
)url
-\n    
(time
-1999-06-05 15:53:43
)time
-\n    
(author
-CmdrTaco
)author
-\n    
(department
-faster-porn
)department
-\n    
(topic
-internet
)topic
-\n    
(comments
-66
)comments
-\n    
(section
-articles
)section
-\n    
(image
-topicinternet.jpg
)image
-\n  
)story
-\n 
(story
-\n    
(title
-Suppression of cold fusion research?
)title
-\n    
(url
-http://slashdot.org/articles/99/06/04/2313200.shtml
)url
-\n    
(time
-1999-06-04 23:12:29
)time
-\n    
(author
-Hemos
)author
-\n    
(department
-possibly-probably
)department
-\n    
(topic
-science
)topic
-\n    
(comments
-217
)comments
-\n    
(section
-articles
)section
-\n    
(image
-topicscience.gif
)image
-\n  
)story
-\n 
(story
-\n    
(title
-California Gov. Halts Wage Info Sale
)title
-\n    
(url
-http://slashdot.org/articles/99/06/04/235256.shtml
)url
-\n    
(time
-1999-06-04 23:05:34
)time
-\n    
(author
-Hemos
)author
-\n    
(department
-woo-hoo!
)department
-\n    
(topic
-usa
)topic
-\n    
(comments
-16
)comments
-\n    
(section
-articles
)section
-\n    
(image
-topicus.gif
)image
-\n  
)story
-\n 
(story
-\n    
(title
-Red Hat Announces IPO
)title
-\n    
(url
-http://slashdot.org/articles/99/06/04/0849207.shtml
)url
-\n    
(time
-1999-06-04 19:30:18
)time
-\n    
(author
-Justin
)author
-\n    
(department
-details-sketchy
)department
-\n    
(topic
-redhat
)topic
-\n    
(comments
-155
)comments
-\n    
(section
-articles
)section
-\n    
(image
-topicredhat.gif
)image
-\n  
)story
-\n
)ultramode



#!/usr/bin/env python
# $Id: test.py 2 2004-08-20 10:48:47Z znek $
from sys          import *
from Foundation   import *
from eoaccess     import *
from EOControl    import *
from NGExtensions import *
from GDLExtensions import *
import resource;

defaults = NSUserDefaults();

connDict = defaults["LSConnectionDictionary"];
if connDict is None:
    print "missing connection dictionary\n";
    exit(1);

primKeyGenDict = defaults["pkeyGeneratorDictionary"];
print primKeyGenDict;
if primKeyGenDict is None:
    print "missing pkeyGeneratorDictionary\n";
    exit(1);


print "ConnectionDictionary: ";
print connDict.description();

adaptorName = defaults["LSAdaptor"];
if adaptorName is None:
    adaptorName = "Sybase10";

adaptor = EOAdaptor(adaptorName);
adaptor.setConnectionDictionary(connDict);
adaptor.setPkeyGeneratorDictionary(primKeyGenDict);

adContext = adaptor.createAdaptorContext();
adChannel = adContext.createAdaptorChannel();

def test_database_channel():
    print "adChannel " + adChannel.description() + "\n";
    print "channel   ";
    print "attributesForTableName doc";
    print adChannel.invoke1("attributesForTableName:", "doc");
    print "primaryKeyAttributesForTableName document  _______________________________________\n";
    print adChannel.invoke1("primaryKeyAttributesForTableName:", "document");
    print "primaryKeyAttributesForTableName:, doc _______________________________________\n";    
    print adChannel.invoke1("primaryKeyAttributesForTableName:", "doc");
    print "primaryKeyAttributesForTableName company _______________________________________\n";    
    print adChannel.invoke1("primaryKeyAttributesForTableName:", "company");
    print "primaryKeyAttributesForTableName person_______________________________________\n";    
    print adChannel.invoke1("primaryKeyAttributesForTableName:", "person");
    print "_______________________________________\n";    

def test_adaptor_data_source():
    adaptor = adChannel.adaptorContext().adaptor();
    dict = NSMutableDictionary();
    dict["login"]      = "jan_1";
    dict["name"]       = "JR";
    dict["firstname"]  = "jan";
    dict["is_person"]  = 1;
    dict["number"]     = "12345_1";
    dict["birthday"]   = NSCalendarDate('1999-09-21 13:23', '%Y-%m-%d %H:%M');
    dict["middlename"] = "Ein Unnuetzer middlename";
    

    dataSource = EOAdaptorDataSource(adChannel);
    hints = NSMutableDictionary();
    pks   = NSMutableArray();
    pks.addObject("company_id");
    hints.setObjectForKey(pks, "EOPrimaryKeyAttributeNamesHint")
    
    fetchSpec = EOFetchSpecification();
    fetchSpec.setEntityName("company");
    fetchSpec.setHints(hints);

    dataSource.setFetchSpecification(fetchSpec);
    print "-------------------- {insert ---------------------\n";
    dataSource.insertObject(dict);
    print "-------------------- insert} ---------------------\n";

    print "-------------------- {select with hints ---------------------\n";
    qualifier = EOQualifier("login = %@", ("jan_1", ))
    fetchSpec = EOFetchSpecification();
    fetchSpec.setQualifier(qualifier);
    fetchSpec.setEntityName("company");
    
    hints = NSMutableDictionary();
    pks.addObject("company_id");
    hints.setObjectForKey(NSTimeZone('MET'), "EOFetchResultTimeZoneHint")
    fetchSpec.setHints(hints);

    sortOrderings = NSMutableArray();
    sortOrderings.addObject(EOSortOrdering("login", "compareCaseInsensitiveAscending:"));
    sortOrderings.addObject(EOSortOrdering("company_id", "compareCaseInsensitiveDescending:"));    
    fetchSpec.setSortOrderings(sortOrderings);
    dataSource = EOAdaptorDataSource(adChannel);
    dataSource.setFetchSpecification(fetchSpec);
    objs = dataSource.fetchObjects();
    print objs;
    print "-------------------- select} ---------------------\n";
    obj = objs[0];

    print "-------------------- {update ---------------------\n";
    print obj;
    obj["login"]      = "jan_1_1";
    obj["middlename"] = EONull();
    dataSource.updateObject(obj);
    print "-------------------- update} ---------------------\n";

    qualifier = EOQualifier("login caseInsensitiveLike %@", ("jan_1_*", ))
    fetchSpec.setQualifier(qualifier);
    dataSource.setFetchSpecification(fetchSpec);
    
    print "-------------------- {select ---------------------\n";
    objs = dataSource.fetchObjects();
    print objs;    
    print "-------------------- select} ---------------------\n";

    print "-------------------- {delete ---------------------\n";
    obj = objs[0];
    dataSource.deleteObject(obj);
    print "-------------------- delete} ---------------------\n";

    print "-------------------- {select ---------------------\n";
    objs = dataSource.fetchObjects();
    print objs;    
    print "-------------------- select} ---------------------\n";


def test_cascaded_datasources():

    adaptor = adChannel.adaptorContext().adaptor();
    dict = NSMutableDictionary();
    dict["login"]      = "jan_1";
    dict["name"]       = "JR";
    dict["firstname"]  = "jan";
    dict["is_person"]  = 1;
    dict["number"]     = "12345_1";

    dataSource      = EOAdaptorDataSource(adChannel);
    fetchSpec = EOFetchSpecification();
    fetchSpec.setEntityName("company");
    qualifier = EOQualifier("login like %@", ("j%", ))
    fetchSpec = EOFetchSpecification();
    fetchSpec.setQualifier(qualifier);
    fetchSpec.setEntityName("company");
    sortOrderings = NSMutableArray();
    sortOrderings.addObject(EOSortOrdering("login", "compareCaseInsensitiveAscending:"));
    fetchSpec.setSortOrderings(sortOrderings);    
    hints = NSMutableDictionary();
    pks   = NSMutableArray();
    pks.addObject("company_id");
    hints.setObjectForKey(pks, "EOPrimaryKeyAttributeNamesHint")
    
    fetchSpec.setHints(hints);

    dataSource.setFetchSpecification(fetchSpec);
    cacheDataSource = EOCacheDataSource(dataSource);    
    objs = dataSource.fetchObjects();
    print objs;
    print cacheDataSource.fetchObjects();
    print "-----------------------------\n";
    print cacheDataSource.fetchObjects();
    dataSource.insertObject(dict);
    print "++++++++++++++++++++++++++++\n";

    fetchSpec = EOFetchSpecification();
    fetchSpec.setEntityName("company");
    qualifier = EOQualifier("login = %@", ("jan_1", ))
    fetchSpec = EOFetchSpecification();
    fetchSpec.setQualifier(qualifier);
    fetchSpec.setEntityName("company");
    dataSource.setFetchSpecification(fetchSpec);
    cacheDataSource = EOCacheDataSource(dataSource);    
    objs = dataSource.fetchObjects();
    obj = objs[0];
    print objs;
    print "-----------------------------\n";
    print cacheDataSource.deleteObject(obj);
    print "++++++++++++++++++++++++++++\n";    
    print cacheDataSource.fetchObjects();

def echo_logins(objs):
    for o in objs:
        print o['login'];

def test_sort_datasource():
    dataSource      = EOAdaptorDataSource(adChannel);

    fetchSpec = EOFetchSpecification();
    fetchSpec.setEntityName("company");
    qualifier = EOQualifier("login like %@", ("%a%", ))
    fetchSpec.setQualifier(qualifier);
    
    dataSource.setFetchSpecification(fetchSpec);
    echo_logins(dataSource.fetchObjects());

    sortOrderings = NSMutableArray();
    sO = EOSortOrdering("login", "compareDescending:");
    sortOrderings.addObject(sO);
    fetchSpec.setSortOrderings(sortOrderings);
    dataSource.setFetchSpecification(fetchSpec);

    echo_logins(dataSource.fetchObjects());

print resource.getrlimit(resource.RLIMIT_CORE);
if adChannel.openChannel():
    print "open channel ok";
else:
    print "open channel failed";
    exit(1);
print "adChannel ", adChannel;


#test_database_channel();
test_adaptor_data_source();
#test_cascaded_datasources();
#test_sort_datasource();
